summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorcbzxt <38526218+cbzxt@users.noreply.github.com>2019-09-25 20:32:46 +0530
committerYu Watanabe <watanabe.yu+github@gmail.com>2019-09-26 00:02:46 +0900
commit37afb0ac787783a1635165b8a4e3ba5fbd007dfd (patch)
tree701346ca9ca7a793dde364401b557fbe0df4bf93
parent508133917d9628f8c0adc5db34d595196b72b1c8 (diff)
downloadsystemd-37afb0ac787783a1635165b8a4e3ba5fbd007dfd.tar.gz
Updated log message when the timesync happens for the first time (#13624)
-rw-r--r--src/timesync/timesyncd-manager.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/timesync/timesyncd-manager.c b/src/timesync/timesyncd-manager.c
index 604c7e01be..72b6bb8eb7 100644
--- a/src/timesync/timesyncd-manager.c
+++ b/src/timesync/timesyncd-manager.c
@@ -617,9 +617,9 @@ static int manager_receive_response(sd_event_source *source, int fd, uint32_t re
m->good = true;
server_address_pretty(m->current_server_address, &pretty);
- /* "for the first time", as further successful syncs will not be logged. */
- log_info("Synchronized to time server for the first time %s (%s).", strna(pretty), m->current_server_name->string);
- sd_notifyf(false, "STATUS=Synchronized to time server for the first time %s (%s).", strna(pretty), m->current_server_name->string);
+ /* "Initial", as further successful syncs will not be logged. */
+ log_info("Initial synchronization to time server %s (%s).", strna(pretty), m->current_server_name->string);
+ sd_notifyf(false, "STATUS=Initial synchronization to time server %s (%s).", strna(pretty), m->current_server_name->string);
}
r = manager_arm_timer(m, m->poll_interval_usec);